@@ -10,7 +10,8 @@ class API:
         }
         self.api = {
             "lista_canales": "/bot/",
-            "new_stats": f"/bot/stats/new"
+            "new_stats": f"/bot/stats/new",
+            "owner": "/bot/owner"
         }
 
     def lista_canales(self):
@@ -21,6 +22,10 @@ class API:
         res = self.peticion_post(self.endpoint("new_stats"), data)
         return res.get('data', None)
 
+    def get_owner(self):
+        res = self.peticion_get(self.endpoint("owner"))
+        return res.get('data', None)
+
     def endpoint(self, nombre):
         if nombre not in self.api:
             return None
