@@ -26,8 +26,9 @@ class Chat:
         self.hilo.start()
         self.status_check = "<connection_status>"
         self.pendientes = []
+        self.callback_function = {}
 
-    def enviar(self, mensaje: str):
+    def enviar(self, mensaje: str, callback_user=None, callback_function=None):
         hashtags = {}
         for palabra in mensaje.split(" "):
             if palabra.startswith("#") and palabra[1:]:
@@ -45,6 +46,8 @@ class Chat:
         }
         if self.sock_connected:
             self.sock.send(json.dumps(mensaje))
+            if callback_function:
+                self.callback_function[callback_user] = callback_function
         else:
             self.pendientes.append(mensaje)
 
@@ -71,7 +74,7 @@ class Chat:
         if not msg_content or mensaje.get('message') == self.status_check:
             return
 
-        if mensaje.get('message').startswith('/'):
+        if mensaje.get('message').startswith('/') or self.callback_function.get(mensaje.get('sender', {}).get('uuid')):
             command = mensaje.get('message')[1:].split(" ")[0]
             if command in self.hyper_chat.rutas.keys():
                 if f := self.hyper_chat.rutas.get(command, None):
@@ -79,6 +82,12 @@ class Chat:
                                         ciphered_nonce=mensaje.get('nonce'),
                                         ciphered_tag=mensaje.get('tag')))
                     f(mensaje)
+            elif self.callback_function.get(mensaje.get('sender', {}).get('uuid')):
+                mensaje.update(dict(ciphered=ciphered_msg,
+                                    ciphered_nonce=mensaje.get('nonce'),
+                                    ciphered_tag=mensaje.get('tag')))
+                f = self.callback_function.pop(mensaje.get('sender', {}).get('uuid'))
+                f(mensaje)
 
     def __on_close(self, ws, close_status_code, close_msg):
         self.sock_connected = False
